@@ -19,5 +19,5 @@ CBLAS_INDEX cblas_idamax( const int N, const double *X, const int incX)
    #define F77_incX incX
 #endif
    F77_idamax_sub( &F77_N, X, &F77_incX, &iamax);
-   return iamax;
+   return iamax ? iamax-1 : 0;
 }
